#
# spec file for package python-distutils-extra
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-distutils-extra
Version:        3.0
Release:        2.9
Summary:        Distutils/Setuptools Adapter
License:        GPL-2.0-only
Group:          Development/Libraries/Python
URL:            https://salsa.debian.org/python-team/packages/python-distutils-extra
Source:         %{url}/-/archive/%{version}/python-distutils-extra-%{version}.tar.bz2
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
BuildArch:      noarch
%python_subpackages

%description
This package adds support for common build additions to distutils.
This includes the following:

  * gettext/i18n
  * documentation
  * program icons

%prep
%setup -q

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc debian/changelog doc/*
%license LICENSE
%{python_sitelib}/*

%changelog
* Thu Nov 23 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add python-setuptools Requires: Version 3.0 has been ported to
  use setuptools.
* Tue Nov 14 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0:
  * Port code to setuptools. It will not work with distutils any
    more.
  * Format code with black and imports with isort.
  * Address pycodestyle and pylint complaints.
  * Use python3 in shebangs.
  * Fix TypeError when calling pylint command.
  * Drop obsolete python3-distutils dependency.
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 2.50:
  * Fix KeyError on .egg-info files in debian directory
    (regression in 2.48)
  * setup.py: Check that Debian version starts with
    DistUtilsExtra version
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 2.49:
  * Add missing python3-setuptools Depends
  * Adapt tests to setuptools 54+
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 2.47:
  * Sort files in POTFILES.in (for stable .pot files)
  * Set Rules-Requires-Root: no
* Mon May  2 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.45
  * Run unittest.main() only when running script directly.
  * Fix install_auto command with --skip-build
    python-distutils-extra seems to rely on a very bad practice of modifying
    internal state (file lists) in middle of `build` commands.  As a result,
    if the package is installed via `build` command followed by `install
  - -skip-build` (since everything was built already!), most of the files
    are not installed.
- Update to version 2.44
  * Drop python2 support
- Update to version 2.43
  * Fix minor typo.
- Update to version 2.42
  * Adjust dependency calculation for Python 3.7.
    For builtin modules, their __file__ attribute is now None instead of
    absent.
    Make the `test/auto.py T.test_apport_hook` stricter and fail more
    usefully.
  * Fix pyflakes3 errors and check it during build
- Move to new debian maintained upstream
* Fri Sep 18 2020 John Vandenberg <jayvdb@gmail.com>
- Add fdupes
- Update to v2.39
  * Ignore comment in second line when parsing *.ui files
  * test/auto.py: Show exactly which modules are missing
* Wed Mar 13 2019 qzheng <qzheng@suse.com>
- Make use of %%license macro and get ready for submitting this
  package (the dependency of onboard) to SLE-15
  (fate#326794, bsc#1082318).
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Sun Sep  8 2013 os-dev@jacraig.com
- Update to 2.38:
  * Use yelp-tools style help installation.
* Sat Sep 29 2012 os-dev@jacraig.com
- Update to 2.37:
  * Handle Glade .ui files correctly when generating the copyright file. Also
    ignore backup files.
  * auto.py: Recognize manpages which have comments before the initial .TH
    comment.
* Wed Sep 12 2012 os-dev@jacraig.com
- Update to version 2.36:
  * Use python 2.6 friendly sys.version_info test.
  * Do not call decode() with an "errors" keyword, as this does not
    yet work with Python 2.6.
- No changelog provided for 2.35.
- Changes from 2.34:
  * Fix *.ui detection to be robust for non-ASCII files.
  * Fix a regression with python2 if files have some utf-8 directives.
- Changes from 2.33:
  * Fix crash when encountering binary files with Python 3.
  * Fix crash when encountering an UTF-8 Python source code file.
* Wed Mar 14 2012 vuntz@opensuse.org
- Update to version 2.32. Summary of changes since 2.23:
  + Port code to be fully Python 3 compatible.
  + Rename "check" command to "pylint".
  + Add support for installing GSettings schema files.
  + Properly support GI repository module detection.
  + Remove pykdeuic4 integration.
  + Drop support for the long-obsolete PolicyKit (pre polkit 1.0
    API).
  + Several bug fixes.
* Thu Jan 12 2012 saschpe@suse.de
- Specfile cleanup:
  * SPDX-style license (GPL-2.0)
  * Remove %%clean section (sane default)
  * Simpler macro usage
  * No authors in description
* Sat Dec 11 2010 rwobben@hotmail.com
- Update to 2.23
  According to this page https://launchpad.net/python-distutils-extra/trunk/2.23) this release has no changelog
* Sat Oct 30 2010 rwobben@hotmail.com
- Update to version 2.22 ( 2.6 is not the latest one)
  Changelog to 2.22
  * setup.py: Drop import of "commands"; unused, and does not exist in
    python3.
  * DistUtilsExtra/command/build_extra.py: Use "in" operator instead of
    has_key(). It's more elegant and Python 3 compatible.
  * test/auto.py: Use Python3 compatible octal constant.
  * test/auto.py: Decode stdout/stderr result from subprocess from bytes to
    str, to work with Python3.
  * test/auto.py: Use whichever Python interpreter we got invoked with (using
    /proc/self/exe) instead of hardcoding "python". With that we can run the
    tests through python3 as well.
  * DistUtilsExtra/auto.py: Port from deprecated "compiler" module to current
    "ast" module.
  * test/auto.py: Only set PYTHONPATH if it isn't set already, so that we can
    override it from outside.
  * test/auto.py: Do not require that "setup.py clean -a" doesn't print
    anything to stderr; with Python 3.1 it now sends out warnings about
    nonexisting directories.
  * test/auto.py: Changed print statements to work with both Python 2 and 3.
  * DistUtilsExtra/command/build_extra.py: Drop unnecessary hashbang line.
  * test/auto.py: Filter out bogus errors about missing files which current
    Python 3 distutils spews out.
  * test/auto.py, Use python{,3}-{pkg-resources,httplib2} as
    external test modules instead of -xdg and -dateutil, since the latter are
    not available for Python 3 yet.
  Changelog to 2.20
  [Didier Roche ]
  * build_i18n.py: add support for LINGUAS (Siegfried Gevatter) (LP: #510957)
  [ Martin Pitt ]
  * debian/local/python-mkdebian: Make langpack.mk include optional, as it
  only exists in Ubuntu, not Debian. (Closes: #589802)
  * debian/local/python-mkdebian: If we are on Debian, set upload target to
  "unstable". (Closes: #589794)
  changelog to 2.19
  * auto.py: Also recognize Qt .ui files if they start with an "<?xml..."
  first line. (LP: #543707)
  * test/auto.py: Check that automatic translation extraction also works for
  extensionless files and single quotation marks. (Side discussion in
  LP #533565)
  * test/auto.py: Check that scripts explicitly mentioned in "data_files" and
  "scripts" are covered by the automatic POTFILES.in generation. This
  reproduces LP #533565.
  * auto.py: Include scripts in setup.py's data_files into potential
  POTFILES.in candidates. (LP: #533565)
  * debian/control: Swap maintainer (me) and uploaders (Sebastian), since I'm
  the de-facto maintainer now.
  * debian/control: Replace python-all-dev build dependency with python-all,
  which is enough. Also wrap build dependencies.
  * Add debian/source/format: 3.0 (native).
  * setup.py: Grab version from DistUtilsExtra/auto.py instead of duplicating
  and hardcoding it.
  * python_mkdebian: Add --version option.
  * Move primary __version__ definition to DistUtilsExtra/__init__.py, where
  it makes more sense than just in the auto module.
  * Add debian/local/python-mkdebian.1. (Closes: #546266)
  * Add debian/python-distutils-extra.manpages to install the new manpage.
* Fri Oct 29 2010 rwobben@hotmail.com
- Update to version 2.6
* Fri Oct 29 2010 rwobben@hotmail.com
- Update to version 2.22
* Fri Apr  2 2010 vuntz@opensuse.org
- Update to version 2.18.
* Tue Sep 22 2009 jblunck@suse.de
- Update to python-distuils-extra 2.10
* Tue Aug 25 2009 jfunk@funktronics.ca
- Build as noarch on 11.2
* Fri Aug 14 2009 jfunk@funktronics.ca
- Cleanup for Factory submission
